@@ -1,17 +1,17 @@
 package version
 
 var (
-	Version = "7.8.3"
+	Version = "7.8.6"
 	// PriorVersion - prior version
-	PriorVersion = "7.8.2"
+	PriorVersion = "7.8.5"
 )
 
 const (
 	// LatestVersion product version supported
-	LatestVersion        = "7.8.3"
-	CompactLatestVersion = "783"
+	LatestVersion        = "7.8.6"
+	CompactLatestVersion = "786"
 	// LastMicroVersion product version supported
-	LastMicroVersion = "7.8.2"
+	LastMicroVersion = "7.8.5"
 	// LastMinorVersion product version supported
 	LastMinorVersion = "7.7.0"
 )
@@ -26,6 +26,9 @@ var OperandVersionFromOperatorVersion map[string]string = map[string]string{
 	"7.8.1":  "7.8.1",
 	"7.8.2":  "7.8.2",
 	"7.8.3":  "7.8.3",
+	"7.8.4":  "7.8.4",
+	"7.8.5":  "7.8.5",
+	"7.8.6":  "7.8.6",
 }
 var FullVersionFromMinorVersion map[string]string = map[string]string{
 	"70": "7.7.0",
@@ -33,6 +36,9 @@ var FullVersionFromMinorVersion map[string]string = map[string]string{
 	"81": "7.8.1",
 	"82": "7.8.2",
 	"83": "7.8.3",
+	"84": "7.8.4",
+	"85": "7.8.5",
+	"86": "7.8.6",
 }
 
 var CompactFullVersionFromMinorVersion map[string]string = map[string]string{
@@ -41,6 +47,9 @@ var CompactFullVersionFromMinorVersion map[string]string = map[string]string{
 	"81": "781",
 	"82": "782",
 	"83": "783",
+	"84": "784",
+	"85": "785",
+	"86": "786",
 }
 
 var CompactVersionFromVersion map[string]string = map[string]string{
@@ -49,6 +58,9 @@ var CompactVersionFromVersion map[string]string = map[string]string{
 	"7.8.1": "781",
 	"7.8.2": "782",
 	"7.8.3": "783",
+	"7.8.4": "784",
+	"7.8.5": "785",
+	"7.8.6": "786",
 }
 
 var FullVersionFromCompactVersion map[string]string = map[string]string{
@@ -57,6 +69,9 @@ var FullVersionFromCompactVersion map[string]string = map[string]string{
 	"781": "7.8.1",
 	"782": "7.8.2",
 	"783": "7.8.3",
+	"784": "7.8.4",
+	"785": "7.8.5",
+	"786": "7.8.6",
 }
 
 var MinorVersionFromFullVersion map[string]string = map[string]string{
@@ -65,6 +80,9 @@ var MinorVersionFromFullVersion map[string]string = map[string]string{
 	"7.8.1": "81",
 	"7.8.2": "82",
 	"7.8.3": "83",
+	"7.8.4": "84",
+	"7.8.5": "85",
+	"7.8.6": "86",
 }
 
 //The yacfg profile to use for a given full version of broker
@@ -74,5 +92,8 @@ var YacfgProfileVersionFromFullVersion map[string]string = map[string]string{
 	"7.8.1": "7.8.1",
 	"7.8.2": "7.8.2",
 	"7.8.3": "7.8.2",
+	"7.8.4": "7.8.2",
+	"7.8.5": "7.8.2",
+	"7.8.6": "7.8.2",
 }
 var YacfgProfileName string = "amq_broker"
